/*
 * SME^2 DFKI GmbH 2007
 * Refer to license.txt for copyright details.
 */
package de.dfki.sme2;

import java.net.URL;
import java.util.Hashtable;
import java.util.Vector;

/**
 * SME<sup>2</sup> matchmaker evaluation environment  
 * plugin interface.<p>
 *
 * The evaluation environment loads a plugin and instantiates
 * the class implementing this interface (the class is specified
 * in <tt>plugin.xml</tt>).<p>
 *
 * The {@link #input} method is called
 * to let the matchmaker initialize and parse the advertised services.
 * This can be a time consuming operation and will not be counted
 * in the average query response time (<tt>aqrt</tt>). However,
 * it will be counted into the total execution time.<p>
 *
 * After the initialization is complete the matchmaker should be ready to
 * process queries. Queries are performed by calling {@link #query} method.
 */
public interface IMatchmakerPlugin {

    /**
     * Initializes matchmaker.<p>
     *
     * Advertised services identified by <code>serviceURL</code> should be
     * processed in this method. After returning from this method the matchmaker
     * should be initialized and ready to accept queries.<p>
     *
     * @param serviceURL URL identifying advertised services. It can be
     * either a file or a directory.
     *
     * @see java.net.URL
     */
    void input (URL serviceURL);


    /**
     * Performs a query returning matched services, sorted by
     * matching factor.<p>
     *
     * This function must perform one or more queries identified
     * by <code>queryURL</code> parameter. The result is a container
     * of &lt; query, container of matched services &gt; pairs.<p>
     *
     * The container must be sorted by matching factor.
     * First item in the container must the closest match etc.<p>
     *
     * @param queryURL URL identifying queries. It can be either a file or a directory.
     * @return Container of queries and query results. The results must be sorted
     * by matching factor. The first item in the container must be the closest match.
     *
     * @see java.util.Hashtable
     * @see java.net.URL
     */
    Hashtable<URL,Vector<URL>> query (URL queryURL);

} // IMatchmakerPlugin
